@@ -1,16 +1,24 @@
 <?php
-
 /**
-  @version   v5.20.19  13-Dec-2020
-  @copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
-  @copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
-  Released under both BSD license and Lesser GPL library license.
-  Whenever there is any discrepancy between the two licenses,
-  the BSD license will take precedence.
+ * Data Dictionary for DB2.
+ *
+ * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
+ *
+ * @package ADOdb
+ * @link https://adodb.org Project's web site and documentation
+ * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
+ *
+ * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
+ * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
+ * any later version. This means you can use it in proprietary products.
+ * See the LICENSE.md file distributed with this source code for details.
+ * @license BSD-3-Clause
+ * @license LGPL-2.1-or-later
+ *
+ * @copyright 2000-2013 John Lim
+ * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
+ */
 
-  Set tabs to 4 for best viewing.
-
-*/
 // security - hide paths
 if (!defined('ADODB_DIR')) die();
 
@@ -18,7 +26,12 @@ class ADODB2_db2 extends ADODB_DataDict {
 
 	var $databaseType = 'db2';
 	var $seqField = false;
+	var $dropCol = 'ALTER TABLE %s DROP COLUMN %s';
 
+	public $blobAllowsDefaultValue = true;
+	public $blobAllowsNotNull      = true;
+
+	
  	function ActualType($meta)
 	{
 		switch($meta) {
@@ -60,21 +73,66 @@ class ADODB2_db2 extends ADODB_DataDict {
 		return $suffix;
 	}
 
-	function AlterColumnSQL($tabname, $flds, $tableflds='',$tableoptions='')
+	function alterColumnSQL($tabname, $flds, $tableflds='',$tableoptions='')
 	{
-		if ($this->debug) ADOConnection::outp("AlterColumnSQL not supported");
-		return array();
+		$tabname = $this->TableName ($tabname);
+		$sql = array();
+		list($lines,$pkey,$idxs) = $this->_GenFields($flds);
+		// genfields can return FALSE at times
+		if ($lines == null) $lines = array();
+		$alter = 'ALTER TABLE ' . $tabname . $this->alterCol . ' ';
+		
+		$dataTypeWords = array('SET','DATA','TYPE');
+		
+		foreach($lines as $v) 
+		{
+			/*
+			 * We must now post-process the line to insert the 'SET DATA TYPE'
+			 * text into the alter statement
+			 */
+			$e = explode(' ',$v);
+			
+			array_splice($e,1,0,$dataTypeWords);
+			
+			$v = implode(' ',$e);
+			
+			$sql[] = $alter . $v;
+		}
+		if (is_array($idxs)) 
+		{
+			foreach($idxs as $idx => $idxdef) {
+				$sql_idxs = $this->CreateIndexSql($idx, $tabname, $idxdef['cols'], $idxdef['opts']);
+				$sql = array_merge($sql, $sql_idxs);
+			}
+
+		}
+		return $sql;
 	}
 
 
-	function DropColumnSQL($tabname, $flds, $tableflds='',$tableoptions='')
+	
+	function dropColumnSql($tabname, $flds, $tableflds='',$tableoptions='')
 	{
-		if ($this->debug) ADOConnection::outp("DropColumnSQL not supported");
-		return array();
+		
+		
+		$tabname = $this->connection->getMetaCasedValue($tabname);
+		$flds    = $this->connection->getMetaCasedValue($flds);
+		
+		if (ADODB_ASSOC_CASE  == ADODB_ASSOC_CASE_NATIVE )
+		{
+			/*
+			 * METACASE_NATIVE
+			 */
+			$tabname = $this->connection->nameQuote . $tabname . $this->connection->nameQuote;
+			$flds    = $this->connection->nameQuote . $flds . $this->connection->nameQuote;
+		}
+		$sql = sprintf($this->dropCol,$tabname,$flds);
+		return (array)$sql;
+
 	}
+    
 
-
-	function ChangeTableSQL($tablename, $flds, $tableoptions = false)
+	function changeTableSQL($tablename, $flds, $tableoptions = false, $dropOldFields=false)
 	{
 
 		/**
@@ -86,17 +144,25 @@ class ADODB2_db2 extends ADODB_DataDict {
 		$validTypes = array("CHAR","VARC");
 		$invalidTypes = array("BIGI","BLOB","CLOB","DATE", "DECI","DOUB", "INTE", "REAL","SMAL", "TIME");
 		// check table exists
-		$cols = $this->MetaColumns($tablename);
+		
+		
+		$cols = $this->metaColumns($tablename);
 		if ( empty($cols)) {
-			return $this->CreateTableSQL($tablename, $flds, $tableoptions);
+			return $this->createTableSQL($tablename, $flds, $tableoptions);
 		}
 
 		// already exists, alter table instead
 		list($lines,$pkey) = $this->_GenFields($flds);
-		$alter = 'ALTER TABLE ' . $this->TableName($tablename);
+		$alter = 'ALTER TABLE ' . $this->tableName($tablename);
 		$sql = array();
 
 		foreach ( $lines as $id => $v ) {
+			/*
+			 * If the metaCasing was NATIVE the col returned with nameQuotes
+			 * around the field. We need to remove this for the metaColumn
+			 * match
+			 */
+			$id = str_replace($this->connection->nameQuote,'',$id);
 			if ( isset($cols[$id]) && is_object($cols[$id]) ) {
 				/**
 				  If the first field of $v is the fieldname, and
