@@ -1,21 +1,25 @@
 <?php
-/*
-@version   v5.20.19  13-Dec-2020
-@copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
-@copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
-  Released under both BSD license and Lesser GPL library license.
-  Whenever there is any discrepancy between the two licenses,
-  the BSD license will take precedence.
-Set tabs to 4 for best viewing.
-
-  Latest version is available at http://adodb.org/
-
-  Native mssql driver. Requires mssql client. Works on Windows.
-  To configure for Unix, see
-   	http://phpbuilder.com/columns/alberto20000919.php3
-
-*/
-
+/**
+ * Native MSSQL driver.
+ *
+ * Requires mssql client. Works on Windows.
+ *
+ * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
+ *
+ * @package ADOdb
+ * @link https://adodb.org Project's web site and documentation
+ * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
+ *
+ * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
+ * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
+ * any later version. This means you can use it in proprietary products.
+ * See the LICENSE.md file distributed with this source code for details.
+ * @license BSD-3-Clause
+ * @license LGPL-2.1-or-later
+ *
+ * @copyright 2000-2013 John Lim
+ * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
+ */
 
 // security - hide paths
 if (!defined('ADODB_DIR')) die();
@@ -39,39 +43,7 @@ if (!defined('ADODB_DIR')) die();
 //----------------------------------------------------------------
 
 
-// has datetime converstion to YYYY-MM-DD format, and also mssql_fetch_assoc
-if (ADODB_PHPVER >= 0x4300) {
-// docs say 4.2.0, but testing shows only since 4.3.0 does it work!
-	ini_set('mssql.datetimeconvert',0);
-} else {
-global $ADODB_mssql_mths;		// array, months must be upper-case
-
-
-	$ADODB_mssql_date_order = 'mdy';
-	$ADODB_mssql_mths = array(
-		'JAN'=>1,'FEB'=>2,'MAR'=>3,'APR'=>4,'MAY'=>5,'JUN'=>6,
-		'JUL'=>7,'AUG'=>8,'SEP'=>9,'OCT'=>10,'NOV'=>11,'DEC'=>12);
-}
-
-//---------------------------------------------------------------------------
-// Call this to autoset $ADODB_mssql_date_order at the beginning of your code,
-// just after you connect to the database. Supports mdy and dmy only.
-// Not required for PHP 4.2.0 and above.
-function AutoDetect_MSSQL_Date_Order($conn)
-{
-global $ADODB_mssql_date_order;
-	$adate = $conn->GetOne('select getdate()');
-	if ($adate) {
-		$anum = (int) $adate;
-		if ($anum > 0) {
-			if ($anum > 31) {
-				//ADOConnection::outp( "MSSQL: YYYY-MM-DD date format not supported currently");
-			} else
-				$ADODB_mssql_date_order = 'dmy';
-		} else
-			$ADODB_mssql_date_order = 'mdy';
-	}
-}
+ini_set('mssql.datetimeconvert',0);
 
 class ADODB_mssql extends ADOConnection {
 	var $databaseType = "mssql";
@@ -94,7 +66,6 @@ class ADODB_mssql extends ADOConnection {
 	var $hasGenID = true;
 	var $sysDate = 'convert(datetime,convert(char,GetDate(),102),102)';
 	var $sysTimeStamp = 'GetDate()';
-	var $_has_mssql_init;
 	var $maxParameterLen = 4000;
 	var $arrayClass = 'ADORecordSet_array_mssql';
 	var $uniqueSort = true;
@@ -107,11 +78,6 @@ class ADODB_mssql extends ADOConnection {
 	var $_bindInputArray = true;
 	var $forceNewConnect = false;
 
-	function __construct()
-	{
-		$this->_has_mssql_init = (strnatcmp(PHP_VERSION,'4.1.0')>=0);
-	}
-
 	function ServerInfo()
 	{
 	global $ADODB_FETCH_MODE;
@@ -148,16 +114,16 @@ class ADODB_mssql extends ADOConnection {
 		return " ISNULL($field, $ifNull) "; // if MS SQL Server
 	}
 
-	function _insertid()
+	protected function _insertID($table = '', $column = '')
 	{
 	// SCOPE_IDENTITY()
 	// Returns the last IDENTITY value inserted into an IDENTITY column in
 	// the same scope. A scope is a module -- a stored procedure, trigger,
 	// function, or batch. Thus, two statements are in the same scope if
 	// they are in the same stored procedure, function, or batch.
-        if ($this->lastInsID !== false) {
-            return $this->lastInsID; // InsID from sp_executesql call
-        } else {
+		if ($this->lastInsID !== false) {
+			return $this->lastInsID; // InsID from sp_executesql call
+		} else {
 			return $this->GetOne($this->identitySQL);
 		}
 	}
@@ -165,37 +131,22 @@ class ADODB_mssql extends ADOConnection {
 
 
 	/**
-	* Correctly quotes a string so that all strings are escaped. We prefix and append
-	* to the string single-quotes.
-	* An example is  $db->qstr("Don't bother",magic_quotes_runtime());
-	*
-	* @param s         the string to quote
-	* @param [magic_quotes]    if $s is GET/POST var, set to get_magic_quotes_gpc().
-	*              This undoes the stupidity of magic quotes for GPC.
-	*
-	* @return  quoted string to be sent back to database
-	*/
-	function qstr($s,$magic_quotes=false)
+	 * Correctly quotes a string so that all strings are escaped.
+	 * We prefix and append to the string single-quotes.
+	 * An example is  $db->qstr("Don't bother");
+	 *
+	 * @param string $s            The string to quote
+	 * @param bool   $magic_quotes This param is not used since 5.21.0.
+	 *                             It remains for backwards compatibility.
+	 *
+	 * @return string Quoted string to be sent back to database
+	 *
+	 * @noinspection PhpUnusedParameterInspection
+	 */
+	function qStr($s, $magic_quotes=false)
 	{
- 		if (!$magic_quotes) {
- 			return  "'".str_replace("'",$this->replaceQuote,$s)."'";
-		}
-
- 		// undo magic quotes for " unless sybase is on
- 		$sybase = ini_get('magic_quotes_sybase');
- 		if (!$sybase) {
- 			$s = str_replace('\\"','"',$s);
- 			if ($this->replaceQuote == "\\'")  // ' already quoted, no need to change anything
- 				return "'$s'";
- 			else {// change \' to '' for sybase/mssql
- 				$s = str_replace('\\\\','\\',$s);
- 				return "'".str_replace("\\'",$this->replaceQuote,$s)."'";
- 			}
- 		} else {
- 			return "'".$s."'";
-		}
+		return  "'" . str_replace("'", $this->replaceQuote, $s) . "'";
 	}
-// moodle change end - see readme_moodle.txt
 
 	function _affectedrows()
 	{
@@ -309,7 +260,9 @@ class ADODB_mssql extends ADOConnection {
 			case 'A':
 				$s .= "substring(convert(char(19),$col,0),18,2)";
 				break;
-
+			case 'l':
+				$s .= "datename(dw,$col)";
+				break;
 			default:
 				if ($ch == '\\') {
 					$i++;
@@ -327,8 +280,8 @@ class ADODB_mssql extends ADOConnection {
 	{
 		if ($this->transOff) return true;
 		$this->transCnt += 1;
-	   	$ok = $this->Execute('BEGIN TRAN');
-	   	return $ok;
+		$ok = $this->Execute('BEGIN TRAN');
+		return $ok;
 	}
 
 	function CommitTrans($ok=true)
@@ -451,29 +404,29 @@ class ADODB_mssql extends ADOConnection {
 
 		global $ADODB_FETCH_MODE;
 		$save = $ADODB_FETCH_MODE;
-        $ADODB_FETCH_MODE = ADODB_FETCH_NUM;
-        if ($this->fetchMode !== FALSE) {
-        	$savem = $this->SetFetchMode(FALSE);
-        }
+		$ADODB_FETCH_MODE = ADODB_FETCH_NUM;
+		if ($this->fetchMode !== FALSE) {
+			$savem = $this->SetFetchMode(FALSE);
+		}
 
-        $rs = $this->Execute($sql);
-        if (isset($savem)) {
-        	$this->SetFetchMode($savem);
-        }
-        $ADODB_FETCH_MODE = $save;
+		$rs = $this->Execute($sql);
+		if (isset($savem)) {
+			$this->SetFetchMode($savem);
+		}
+		$ADODB_FETCH_MODE = $save;
 
-        if (!is_object($rs)) {
-        	return FALSE;
-        }
+		if (!is_object($rs)) {
+			return FALSE;
+		}
 
 		$indexes = array();
 		while ($row = $rs->FetchRow()) {
 			if ($primary && !$row[5]) continue;
 
-            $indexes[$row[0]]['unique'] = $row[6];
-            $indexes[$row[0]]['columns'][] = $row[1];
-    	}
-        return $indexes;
+			$indexes[$row[0]]['unique'] = $row[6];
+			$indexes[$row[0]]['columns'][] = $row[1];
+		}
+		return $indexes;
 	}
 
 	function MetaForeignKeys($table, $owner=false, $upper=false)
@@ -488,7 +441,7 @@ class ADODB_mssql extends ADOConnection {
 "select object_name(constid) as constraint_name,
 	col_name(fkeyid, fkey) as column_name,
 	object_name(rkeyid) as referenced_table_name,
-   	col_name(rkeyid, rkey) as referenced_column_name
+	col_name(rkeyid, rkey) as referenced_column_name
 from sysforeignkeys
 where upper(object_name(fkeyid)) = $table
 order by constraint_name, referenced_table_name, keyno";
@@ -509,7 +462,11 @@ order by constraint_name, referenced_table_name, keyno";
 		foreach($arr as $k => $v) {
 			foreach($v as $a => $b) {
 				if ($upper) $a = strtoupper($a);
-				$arr2[$a] = $b;
+				if (is_array($arr2[$a])) {	// a previous foreign key was define for this reference table, we merge the new one
+					$arr2[$a] = array_merge($arr2[$a], $b);
+				} else {
+					$arr2[$a] = $b;
+				}
 			}
 		}
 		return $arr2;
@@ -519,22 +476,24 @@ order by constraint_name, referenced_table_name, keyno";
 	function MetaDatabases()
 	{
 		if(@mssql_select_db("master")) {
-				 $qry=$this->metaDatabasesSQL;
-				 if($rs=@mssql_query($qry,$this->_connectionID)){
-						 $tmpAr=$ar=array();
-						 while($tmpAr=@mssql_fetch_row($rs))
-								 $ar[]=$tmpAr[0];
-						@mssql_select_db($this->database);
-						 if(sizeof($ar))
-								 return($ar);
-						 else
-								 return(false);
-				 } else {
-						 @mssql_select_db($this->database);
-						 return(false);
-				 }
-		 }
-		 return(false);
+			$qry = $this->metaDatabasesSQL;
+			if($rs = @mssql_query($qry,$this->_connectionID)) {
+				$tmpAr = $ar = array();
+				while($tmpAr = @mssql_fetch_row($rs)) {
+					$ar[]=$tmpAr[0];
+				}
+				@mssql_select_db($this->database);
+				if(sizeof($ar)) {
+					return($ar);
+				} else {
+					return(false);
+				}
+			} else {
+				@mssql_select_db($this->database);
+				return(false);
+			}
+		}
+		return(false);
 	}
 
 	// "Stein-Aksel Basma" <basma@accelero.no>
@@ -607,14 +566,18 @@ order by constraint_name, referenced_table_name, keyno";
 		if (!$id) return false;
 		$arr = mssql_fetch_array($id);
 		@mssql_free_result($id);
-		if (is_array($arr)) return $arr[0];
-	   else return -1;
+		if (is_array($arr)) {
+			return $arr[0];
+		} else {
+			return -1;
+		}
 	}
 
 	// returns true or false, newconnect supported since php 5.1.0.
 	function _connect($argHostname, $argUsername, $argPassword, $argDatabasename,$newconnect=false)
 	{
 		if (!function_exists('mssql_pconnect')) return null;
+		if (!empty($this->port)) $argHostname .= ":".$this->port;
 		$this->_connectionID = mssql_connect($argHostname,$argUsername,$argPassword,$newconnect);
 		if ($this->_connectionID === false) return false;
 		if ($argDatabasename) return $this->SelectDB($argDatabasename);
@@ -626,6 +589,7 @@ order by constraint_name, referenced_table_name, keyno";
 	function _pconnect($argHostname, $argUsername, $argPassword, $argDatabasename)
 	{
 		if (!function_exists('mssql_pconnect')) return null;
+		if (!empty($this->port)) $argHostname .= ":".$this->port;
 		$this->_connectionID = mssql_pconnect($argHostname,$argUsername,$argPassword);
 		if ($this->_connectionID === false) return false;
 
@@ -639,9 +603,9 @@ order by constraint_name, referenced_table_name, keyno";
 	}
 
 	function _nconnect($argHostname, $argUsername, $argPassword, $argDatabasename)
-    {
+	{
 		return $this->_connect($argHostname, $argUsername, $argPassword, $argDatabasename, true);
-    }
+	}
 
 	function Prepare($sql)
 	{
@@ -656,31 +620,27 @@ order by constraint_name, referenced_table_name, keyno";
 
 	function PrepareSP($sql,$param=true)
 	{
-		if (!$this->_has_mssql_init) {
-			ADOConnection::outp( "PrepareSP: mssql_init only available since PHP 4.1.0");
-			return $sql;
-		}
 		$stmt = mssql_init($sql,$this->_connectionID);
 		if (!$stmt)  return $sql;
 		return array($sql,$stmt);
 	}
 
 	// returns concatenated string
-    // MSSQL requires integers to be cast as strings
-    // automatically cast every datatype to VARCHAR(255)
-    // @author David Rogers (introspectshun)
-    function Concat()
-    {
-            $s = "";
-            $arr = func_get_args();
+	// MSSQL requires integers to be cast as strings
+	// automatically cast every datatype to VARCHAR(255)
+	// @author David Rogers (introspectshun)
+	function Concat()
+	{
+			$s = "";
+			$arr = func_get_args();
 
-            // Split single record on commas, if possible
-            if (sizeof($arr) == 1) {
-                foreach ($arr as $arg) {
-                    $args = explode(',', $arg);
-                }
-                $arr = $args;
-            }
+			// Split single record on commas, if possible
+			if (sizeof($arr) == 1) {
+				foreach ($arr as $arg) {
+					$args = explode(',', $arg);
+				}
+				$arr = $args;
+			}
 
 			array_walk(
 				$arr,
@@ -688,11 +648,11 @@ order by constraint_name, referenced_table_name, keyno";
 					$value = "CAST(" . $value . " AS VARCHAR(255))";
 				}
 			);
-            $s = implode('+',$arr);
-            if (sizeof($arr) > 0) return "$s";
+			$s = implode('+',$arr);
+			if (sizeof($arr) > 0) return "$s";
 
 			return '';
-    }
+	}
 
 	/*
 	Usage:
@@ -714,11 +674,6 @@ order by constraint_name, referenced_table_name, keyno";
 	*/
 	function Parameter(&$stmt, &$var, $name, $isOutput=false, $maxLen=4000, $type=false)
 	{
-		if (!$this->_has_mssql_init) {
-			ADOConnection::outp( "Parameter: mssql_bind only available since PHP 4.1.0");
-			return false;
-		}
-
 		$isNull = is_null($var); // php 4.0.4 and above...
 
 		if ($type === false)
@@ -728,7 +683,7 @@ order by constraint_name, referenced_table_name, keyno";
 			case 'double': $type = SQLFLT8; break;
 			case 'integer': $type = SQLINT4; break;
 			case 'boolean': $type = SQLINT1; break; # SQLBIT not supported in 4.1.0
-			}
+		}
 
 		if  ($this->debug) {
 			$prefix = ($isOutput) ? 'Out' : 'In';
@@ -780,11 +735,11 @@ order by constraint_name, referenced_table_name, keyno";
 			# bind input params with sp_executesql:
 			# see http://www.quest-pipelines.com/newsletter-v3/0402_F.htm
 			# works only with sql server 7 and newer
-            $getIdentity = false;
-            if (!is_array($sql) && preg_match('/^\\s*insert/i', $sql)) {
-                $getIdentity = true;
-                $sql .= (preg_match('/;\\s*$/i', $sql) ? ' ' : '; ') . $this->identitySQL;
-            }
+			$getIdentity = false;
+			if (!is_array($sql) && preg_match('/^\\s*insert/i', $sql)) {
+				$getIdentity = true;
+				$sql .= (preg_match('/;\\s*$/i', $sql) ? ' ' : '; ') . $this->identitySQL;
+			}
 			if (!is_array($sql)) $sql = $this->Prepare($sql);
 			$params = '';
 			$decl = '';
@@ -805,16 +760,16 @@ order by constraint_name, referenced_table_name, keyno";
 						$decl .= "@P$i NVARCHAR($len)";
 					}
 
-
-					if (substr($v,0,1) == "'" && substr($v,-1,1) == "'")
+					if(substr($v,0,1) == "'" && substr($v,-1,1) == "'")
 						/*
 						* String is already fully quoted
 						*/
 						$inputVar = $v;
 					else
-						$inputVar = $this->qstr($v);
+						$inputVar = $db->this($v);
+
+					$params .= "@P$i=N" . $inputVar;
 
-					$params .= "@P$i=N" . $inputVar;	
 				} else if (is_integer($v)) {
 					$decl .= "@P$i INT";
 					$params .= "@P$i=".$v;
@@ -833,20 +788,20 @@ order by constraint_name, referenced_table_name, keyno";
 			$decl = $this->qstr($decl);
 			if ($this->debug) ADOConnection::outp("<font size=-1>sp_executesql N{$sql[1]},N$decl,$params</font>");
 			$rez = mssql_query("sp_executesql N{$sql[1]},N$decl,$params", $this->_connectionID);
-            if ($getIdentity) {
-                $arr = @mssql_fetch_row($rez);
-                $this->lastInsID = isset($arr[0]) ? $arr[0] : false;
-                @mssql_data_seek($rez, 0);
-            }
+			if ($getIdentity) {
+				$arr = @mssql_fetch_row($rez);
+				$this->lastInsID = isset($arr[0]) ? $arr[0] : false;
+				@mssql_data_seek($rez, 0);
+			}
 
 		} else if (is_array($sql)) {
 			# PrepareSP()
 			$rez = mssql_execute($sql[1]);
-            $this->lastInsID = false;
+			$this->lastInsID = false;
 
 		} else {
 			$rez = mssql_query($sql,$this->_connectionID);
-            $this->lastInsID = false;
+			$this->lastInsID = false;
 		}
 		return $rez;
 	}
@@ -854,26 +809,47 @@ order by constraint_name, referenced_table_name, keyno";
 	// returns true or false
 	function _close()
 	{
-		if ($this->transCnt) $this->RollbackTrans();
-		$rez = @mssql_close($this->_connectionID);
+		if ($this->transCnt) {
+			$this->RollbackTrans();
+		}
+		if($this->_connectionID) {
+			$rez = mssql_close($this->_connectionID);
+		}
 		$this->_connectionID = false;
 		return $rez;
 	}
 
-	// mssql uses a default date like Dec 30 2000 12:00AM
-	static function UnixDate($v)
-	{
-		return ADORecordSet_array_mssql::UnixDate($v);
-	}
 
-	static function UnixTimeStamp($v)
+
+	/**
+	* Returns a substring of a varchar type field
+	*
+	* The SQL server version varies because the length is mandatory, so
+	* we append a reasonable string length
+	*
+	* @param	string	$fld	The field to sub-string
+	* @param	int		$start	The start point
+	* @param	int		$length	An optional length
+	*
+	* @return	The SQL text
+	*/
+	function substr($fld,$start,$length=0)
 	{
-		return ADORecordSet_array_mssql::UnixTimeStamp($v);
+		if ($length == 0)
+			/*
+		     * The length available to varchar is 2GB, but that makes no
+			 * sense in a substring, so I'm going to arbitrarily limit
+			 * the length to 1K, but you could change it if you want
+			 */
+			$length = 1024;
+
+		$text = "SUBSTRING($fld,$start,$length)";
+		return $text;
 	}
 }
 
 /*--------------------------------------------------------------------------------------
-	 Class Name: Recordset
+	Class Name: Recordset
 --------------------------------------------------------------------------------------*/
 
 class ADORecordset_mssql extends ADORecordSet {
@@ -894,7 +870,7 @@ class ADORecordset_mssql extends ADORecordSet {
 
 		}
 		$this->fetchMode = $mode;
-		return parent::__construct($id,$mode);
+		return parent::__construct($id);
 	}
 
 
@@ -930,7 +906,7 @@ class ADORecordset_mssql extends ADORecordSet {
 			}
 		}
 
-		 return $this->fields[$this->bind[strtoupper($colname)]];
+		return $this->fields[$this->bind[strtoupper($colname)]];
 	}
 
 	/*	Returns: an object containing field information.
@@ -970,7 +946,7 @@ class ADORecordset_mssql extends ADORecordSet {
 			}
 			else {
 				if ($this->hasFetchAssoc) {// only for PHP 4.2.0 or later
-					 $this->fields = @mssql_fetch_assoc($this->_queryID);
+					$this->fields = @mssql_fetch_assoc($this->_queryID);
 				} else {
 					$flds = @mssql_fetch_array($this->_queryID);
 					if (is_array($flds)) {
@@ -1027,9 +1003,9 @@ class ADORecordset_mssql extends ADORecordSet {
 					$this->fields = @mssql_fetch_assoc($this->_queryID);
 				else {
 					$this->fields = @mssql_fetch_array($this->_queryID);
-					if (@is_array($$this->fields)) {
+					if (@is_array($this->fields)) {
 						$fassoc = array();
-						foreach($$this->fields as $k => $v) {
+						foreach($this->fields as $k => $v) {
 							if (is_integer($k)) continue;
 							$fassoc[$k] = $v;
 						}
@@ -1075,108 +1051,43 @@ class ADORecordset_mssql extends ADORecordSet {
 		return true;
 	}
 
-	// mssql uses a default date like Dec 30 2000 12:00AM
-	static function UnixDate($v)
+	/**
+	* Returns the maximum size of a MetaType C field. Because of the
+	* database design, SQL Server places no limits on the size of data inserted
+	* Although the actual limit is 2^31-1 bytes.
+	*
+	* @return int
+	*/
+	function charMax()
 	{
-		return ADORecordSet_array_mssql::UnixDate($v);
+		return ADODB_STRINGMAX_NOLIMIT;
 	}
 
-	static function UnixTimeStamp($v)
+	/**
+	* Returns the maximum size of a MetaType X field. Because of the
+	* database design, SQL Server places no limits on the size of data inserted
+	* Although the actual limit is 2^31-1 bytes.
+	*
+	* @return int
+	*/
+	function textMax()
 	{
-		return ADORecordSet_array_mssql::UnixTimeStamp($v);
+		return ADODB_STRINGMAX_NOLIMIT;
 	}
 
 }
 
 
-class ADORecordSet_array_mssql extends ADORecordSet_array {
-	function __construct($id=-1,$mode=false)
-	{
-		parent::__construct($id,$mode);
-	}
-
-		// mssql uses a default date like Dec 30 2000 12:00AM
-	static function UnixDate($v)
-	{
-
-		if (is_numeric(substr($v,0,1)) && ADODB_PHPVER >= 0x4200) return parent::UnixDate($v);
-
-	global $ADODB_mssql_mths,$ADODB_mssql_date_order;
-
-		//Dec 30 2000 12:00AM
-		if ($ADODB_mssql_date_order == 'dmy') {
-			if (!preg_match( "|^([0-9]{1,2})[-/\. ]+([A-Za-z]{3})[-/\. ]+([0-9]{4})|" ,$v, $rr)) {
-				return parent::UnixDate($v);
-			}
-			if ($rr[3] <= TIMESTAMP_FIRST_YEAR) return 0;
-
-			$theday = $rr[1];
-			$themth =  substr(strtoupper($rr[2]),0,3);
-		} else {
-			if (!preg_match( "|^([A-Za-z]{3})[-/\. ]+([0-9]{1,2})[-/\. ]+([0-9]{4})|" ,$v, $rr)) {
-				return parent::UnixDate($v);
-			}
-			if ($rr[3] <= TIMESTAMP_FIRST_YEAR) return 0;
-
-			$theday = $rr[2];
-			$themth = substr(strtoupper($rr[1]),0,3);
-		}
-		$themth = $ADODB_mssql_mths[$themth];
-		if ($themth <= 0) return false;
-		// h-m-s-MM-DD-YY
-		return  mktime(0,0,0,$themth,$theday,$rr[3]);
-	}
-
-	static function UnixTimeStamp($v)
-	{
-
-		if (is_numeric(substr($v,0,1)) && ADODB_PHPVER >= 0x4200) return parent::UnixTimeStamp($v);
-
-	global $ADODB_mssql_mths,$ADODB_mssql_date_order;
-
-		//Dec 30 2000 12:00AM
-		 if ($ADODB_mssql_date_order == 'dmy') {
-			 if (!preg_match( "|^([0-9]{1,2})[-/\. ]+([A-Za-z]{3})[-/\. ]+([0-9]{4}) +([0-9]{1,2}):([0-9]{1,2}) *([apAP]{0,1})|"
-			,$v, $rr)) return parent::UnixTimeStamp($v);
-			if ($rr[3] <= TIMESTAMP_FIRST_YEAR) return 0;
-
-			$theday = $rr[1];
-			$themth =  substr(strtoupper($rr[2]),0,3);
-		} else {
-			if (!preg_match( "|^([A-Za-z]{3})[-/\. ]+([0-9]{1,2})[-/\. ]+([0-9]{4}) +([0-9]{1,2}):([0-9]{1,2}) *([apAP]{0,1})|"
-			,$v, $rr)) return parent::UnixTimeStamp($v);
-			if ($rr[3] <= TIMESTAMP_FIRST_YEAR) return 0;
-
-			$theday = $rr[2];
-			$themth = substr(strtoupper($rr[1]),0,3);
-		}
-
-		$themth = $ADODB_mssql_mths[$themth];
-		if ($themth <= 0) return false;
-
-		switch (strtoupper($rr[6])) {
-		case 'P':
-			if ($rr[4]<12) $rr[4] += 12;
-			break;
-		case 'A':
-			if ($rr[4]==12) $rr[4] = 0;
-			break;
-		default:
-			break;
-		}
-		// h-m-s-MM-DD-YY
-		return  mktime($rr[4],$rr[5],0,$themth,$theday,$rr[3]);
-	}
-}
+class ADORecordSet_array_mssql extends ADORecordSet_array {}
 
 /*
 Code Example 1:
 
-select 	object_name(constid) as constraint_name,
-       	object_name(fkeyid) as table_name,
-        col_name(fkeyid, fkey) as column_name,
+select	object_name(constid) as constraint_name,
+		object_name(fkeyid) as table_name,
+		col_name(fkeyid, fkey) as column_name,
 	object_name(rkeyid) as referenced_table_name,
-   	col_name(rkeyid, rkey) as referenced_column_name
+	col_name(rkeyid, rkey) as referenced_column_name
 from sysforeignkeys
 where object_name(fkeyid) = x
 order by constraint_name, table_name, referenced_table_name,  keyno
