@@ -1,24 +1,30 @@
 <?php
-
-/*
-@version   v5.20.19  13-Dec-2020
-@copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
-@copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
-  Released under both BSD license and Lesser GPL library license.
-  Whenever there is any discrepancy between the two licenses,
-  the BSD license will take precedence.
-  Set tabs to 8.
-
-  MySQL code that supports transactions. For MySQL 3.23 or later.
-  Code from James Poon <jpoon88@yahoo.com>
-  
-  This driver extends the deprecated mysql driver, and was originally designed to be a 
-  portable driver in the same manner as oci8po and mssqlpo. Its functionality
-  is exactly duplicated in the mysqlt driver, which is itself deprecated.
-  This driver will be removed in ADOdb version 6.0.0.
-
-  Requires mysql client. Works on Windows and Unix.
-*/
+/**
+ * Portable MySQL driver
+ *
+ * @deprecated
+ *
+ * Extends the deprecated mysql driver, and was originally designed to be a
+ * portable driver in the same manner as oci8po and mssqlpo. Its functionality
+ * is exactly duplicated in the mysqlt driver, which is itself deprecated.
+ * This driver will be removed in ADOdb version 6.0.0.
+ *
+ * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
+ *
+ * @package ADOdb
+ * @link https://adodb.org Project's web site and documentation
+ * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
+ *
+ * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
+ * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
+ * any later version. This means you can use it in proprietary products.
+ * See the LICENSE.md file distributed with this source code for details.
+ * @license BSD-3-Clause
+ * @license LGPL-2.1-or-later
+ *
+ * @copyright 2000-2013 John Lim
+ * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
+ */
 
 // security - hide paths
 if (!defined('ADODB_DIR')) die();
@@ -32,11 +38,6 @@ class ADODB_mysqlt extends ADODB_mysql {
 	var $hasTransactions = true;
 	var $autoRollback = true; // apparently mysql does not autorollback properly
 
-	function __construct()
-	{
-	global $ADODB_EXTENSION; if ($ADODB_EXTENSION) $this->rsPrefix .= 'ext_';
-	}
-
 	function BeginTrans()
 	{
 		if ($this->transOff) return true;
@@ -116,11 +117,6 @@ class ADORecordSet_mysqlt extends ADORecordSet_mysql{
 
 class ADORecordSet_ext_mysqlt extends ADORecordSet_mysqlt {
 
-	function __construct($queryID,$mode=false)
-	{
-		parent::__construct($queryID,$mode);
-	}
-
 	function MoveNext()
 	{
 		return adodb_movenext($this);
