@@ -1,20 +1,25 @@
 <?php
-/*
-
-  @version   v5.20.19  13-Dec-2020
-  @copyright (c) 2000-2013 John Lim. All rights reserved.
-  @copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
-
-  Released under both BSD license and Lesser GPL library license.
-  Whenever there is any discrepancy between the two licenses,
-  the BSD license will take precedence.
-
-  Latest version is available at http://adodb.org/
-
-  Code contributed by George Fourlanos <fou@infomap.gr>
-
-  13 Nov 2000 jlim - removed all ora_* references.
-*/
+/**
+ * FileDescription
+ *
+ * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
+ *
+ * @package ADOdb
+ * @link https://adodb.org Project's web site and documentation
+ * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
+ *
+ * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
+ * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
+ * any later version. This means you can use it in proprietary products.
+ * See the LICENSE.md file distributed with this source code for details.
+ * @license BSD-3-Clause
+ * @license LGPL-2.1-or-later
+ *
+ * @copyright 2000-2013 John Lim
+ * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
+ * @author John Lim
+ * @author George Fourlanos <fou@infomap.gr>
+ */
 
 // security - hide paths
 if (!defined('ADODB_DIR')) die();
@@ -89,7 +94,6 @@ END;
 	var $connectSID = false;
 	var $_bind = false;
 	var $_nestedSQL = true;
-	var $_hasOciFetchStatement = false;
 	var $_getarray = false; // currently not working
 	var $leftOuter = '';  // oracle wierdness, $col = $value (+) for LEFT OUTER, $col (+)= $value for RIGHT OUTER
 	var $session_sharing_force_blob = false; // alter session on updateblob if set to true
@@ -103,13 +107,20 @@ END;
 
 	// var $ansiOuter = true; // if oracle9
 
-	function __construct()
-	{
-		$this->_hasOciFetchStatement = ADODB_PHPVER >= 0x4200;
-		if (defined('ADODB_EXTENSION')) {
-			$this->rsPrefix .= 'ext_';
-		}
-	}
+	/*
+	 * Legacy compatibility for sequence names for emulated auto-increments
+	 */
+	public $useCompactAutoIncrements = false;
+
+	/*
+	 * Defines the schema name for emulated auto-increment columns
+	 */
+	public $schema = false;
+
+	/*
+	 * Defines the prefix for emulated auto-increment columns
+	 */
+	public $seqPrefix = 'SEQ_';
 
 	/*  function MetaColumns($table, $normalize=true) added by smondino@users.sourceforge.net*/
 	function MetaColumns($table, $normalize=true)
@@ -308,6 +319,42 @@ END;
 		return " NVL($field, $ifNull) "; // if Oracle
 	}
 
+	protected function _insertID($table = '', $column = '')
+	{
+
+		if (!$this->seqField)
+			return false;
+
+		if ($this->schema)
+		{
+			$t = strpos($table,'.');
+			if ($t !== false)
+				$tab = substr($table,$t+1);
+			else
+				$tab = $table;
+
+			if ($this->useCompactAutoIncrements)
+				$tab = sprintf('%u',crc32(strtolower($tab)));
+
+			$seqname = $this->schema.'.'.$this->seqPrefix.$tab;
+		}
+		else
+		{
+			if ($this->useCompactAutoIncrements)
+				$table = sprintf('%u',crc32(strtolower($table)));
+
+			$seqname = $this->seqPrefix.$table;
+		}
+
+		if (strlen($seqname) > 30)
+			/*
+			* We cannot successfully identify the sequence
+			*/
+			return false;
+
+		return $this->getOne("SELECT $seqname.currval FROM dual");
+	}
+
 	// format and return date string in database date format
 	function DBDate($d,$isfld=false)
 	{
@@ -1497,37 +1544,27 @@ SELECT /*+ RULE */ distinct b.column_name
 	}
 
 	/**
-	 * Quotes a string.
-	 * An example is  $db->qstr("Don't bother",magic_quotes_runtime());
+	 * Correctly quotes a string so that all strings are escaped.
+	 * We prefix and append to the string single-quotes.
+	 * An example is  $db->qstr("Don't bother");
 	 *
-	 * @param string $s the string to quote
-	 * @param bool $magic_quotes if $s is GET/POST var, set to get_magic_quotes_gpc().
-	 *             This undoes the stupidity of magic quotes for GPC.
+	 * @param string $s            The string to quote
+	 * @param bool   $magic_quotes This param is not used since 5.21.0.
+	 *                             It remains for backwards compatibility.
 	 *
-	 * @return string quoted string to be sent back to database
+	 * @return string Quoted string to be sent back to database
+	 *
+	 * @noinspection PhpUnusedParameterInspection
 	 */
-	function qstr($s,$magic_quotes=false)
+	function qStr($s, $magic_quotes=false)
 	{
-		//$nofixquotes=false;
-
-		if ($this->noNullStrings && strlen($s)==0) {
+		if ($this->noNullStrings && strlen($s) == 0) {
 			$s = ' ';
 		}
-		if (!$magic_quotes) {
-			if ($this->replaceQuote[0] == '\\'){
-				$s = str_replace('\\','\\\\',$s);
-			}
-			return  "'".str_replace("'",$this->replaceQuote,$s)."'";
-		}
-
-		// undo magic quotes for " unless sybase is on
-		if (!ini_get('magic_quotes_sybase')) {
-			$s = str_replace('\\"','"',$s);
-			$s = str_replace('\\\\','\\',$s);
-			return "'".str_replace("\\'",$this->replaceQuote,$s)."'";
-		} else {
-			return "'".$s."'";
+		if ($this->replaceQuote[0] == '\\'){
+			$s = str_replace('\\','\\\\',$s);
 		}
+		return  "'" . str_replace("'", $this->replaceQuote, $s) . "'";
 	}
 
 }
@@ -1565,7 +1602,7 @@ class ADORecordset_oci8 extends ADORecordSet {
 		$this->adodbFetchMode = $mode;
 		$this->_queryID = $queryID;
 	}
-	
+
 	/**
 	* Overrides the core destructor method as that causes problems here
 	*
@@ -1751,7 +1788,8 @@ class ADORecordset_oci8 extends ADORecordSet {
 			oci_free_cursor($this->_refcursor);
 			$this->_refcursor = false;
 		}
-		@oci_free_statement($this->_queryID);
+		if (is_resource($this->_queryID))
+		   @oci_free_statement($this->_queryID);
 		$this->_queryID = false;
 	}
 
@@ -1808,16 +1846,12 @@ class ADORecordset_oci8 extends ADORecordSet {
 			return 'I';
 
 		default:
-			return 'N';
+			return ADODB_DEFAULT_METATYPE;
 		}
 	}
 }
 
 class ADORecordSet_ext_oci8 extends ADORecordSet_oci8 {
-	function __construct($queryID,$mode=false)
-	{
-		parent::__construct($queryID, $mode);
-	}
 
 	function MoveNext()
 	{
