@@ -1,18 +1,25 @@
 <?php
-/*
-@version   v5.20.19  13-Dec-2020
-@copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
-@copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
-  Released under both BSD license and Lesser GPL library license.
-  Whenever there is any discrepancy between the two licenses,
-  the BSD license will take precedence.
-
-  Latest version is available at http://adodb.org/
-
-  Oracle data driver. Requires Oracle client. Works on Windows and Unix and Oracle 7.
-
-  If you are using Oracle 8 or later, use the oci8 driver which is much better and more reliable.
-*/
+/**
+ * Oracle data driver
+ *
+ * @deprecated Use oci8 driver instead
+ *
+ * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
+ *
+ * @package ADOdb
+ * @link https://adodb.org Project's web site and documentation
+ * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
+ *
+ * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
+ * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
+ * any later version. This means you can use it in proprietary products.
+ * See the LICENSE.md file distributed with this source code for details.
+ * @license BSD-3-Clause
+ * @license LGPL-2.1-or-later
+ *
+ * @copyright 2000-2013 John Lim
+ * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
+ */
 
 // security - hide paths
 if (!defined('ADODB_DIR')) die();
@@ -29,10 +36,6 @@ class ADODB_oracle extends ADOConnection {
 	var $sysTimeStamp = 'SYSDATE';
 	var $connectSID = true;
 
-	function __construct()
-	{
-	}
-
 	// format and return date string in database date format
 	function DBDate($d, $isfld = false)
 	{
