@@ -1,17 +1,23 @@
 <?php
-/*
- @version   v5.20.9  21-Dec-2016
- @copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
- @copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
-  Released under both BSD license and Lesser GPL library license.
-  Whenever there is any discrepancy between the two licenses,
-  the BSD license will take precedence.
-  Set tabs to 4.
-
-  Postgres7 support.
-  28 Feb 2001: Currently indicate that we support LIMIT
-  01 Dec 2001: dannym added support for default values
-*/
+/**
+ * ADOdb PostgreSQL 7 driver
+ *
+ * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
+ *
+ * @package ADOdb
+ * @link https://adodb.org Project's web site and documentation
+ * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
+ *
+ * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
+ * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
+ * any later version. This means you can use it in proprietary products.
+ * See the LICENSE.md file distributed with this source code for details.
+ * @license BSD-3-Clause
+ * @license LGPL-2.1-or-later
+ *
+ * @copyright 2000-2013 John Lim
+ * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
+ */
 
 // security - hide paths
 if (!defined('ADODB_DIR')) die();
@@ -101,7 +107,7 @@ class ADODB_postgres7 extends ADODB_postgres64 {
 		if (ADODB_ASSOC_CASE !== ADODB_ASSOC_CASE_NATIVE) {
 			$this->rsPrefix .= 'assoc_';
 		}
-		$this->_bindInputArray = PHP_VERSION >= 5.1;
+		$this->_bindInputArray = true;
 	}
 
 
@@ -109,6 +115,8 @@ class ADODB_postgres7 extends ADODB_postgres64 {
 	// which makes obsolete the LIMIT limit,offset syntax
 	function SelectLimit($sql,$nrows=-1,$offset=-1,$inputarr=false,$secs2cache=0)
 	{
+		$nrows = (int) $nrows;
+		$offset = (int) $offset;
 		$offsetStr = ($offset >= 0) ? " OFFSET ".((integer)$offset) : '';
 		$limitStr  = ($nrows >= 0)  ? " LIMIT ".((integer)$nrows) : '';
 		if ($secs2cache)
@@ -267,34 +275,47 @@ class ADODB_postgres7 extends ADODB_postgres64 {
 		return $rez;
 	}
 
-	// this is a set of functions for managing client encoding - very important if the encodings
-	// of your database and your output target (i.e. HTML) don't match
-	//for instance, you may have UNICODE database and server it on-site as WIN1251 etc.
-	// GetCharSet - get the name of the character set the client is using now
-	// the functions should work with Postgres 7.0 and above, the set of charsets supported
-	// depends on compile flags of postgres distribution - if no charsets were compiled into the server
-	// it will return 'SQL_ANSI' always
-	function GetCharSet()
+	/**
+	 * Retrieve the client connection's current character set.
+
+	 * If no charsets were compiled into the server, the function will always
+	 * return 'SQL_ASCII'.
+	 * @see https://www.php.net/manual/en/function.pg-client-encoding.php
+	 *
+	 * @return string|false The character set, or false if it can't be determined.
+	 */
+	function getCharSet()
 	{
-		//we will use ADO's builtin property charSet
-		$this->charSet = @pg_client_encoding($this->_connectionID);
-		if (!$this->charSet) {
+		if (!$this->_connectionID) {
 			return false;
-		} else {
-			return $this->charSet;
 		}
+		$this->charSet = pg_client_encoding($this->_connectionID);
+		return $this->charSet ?: false;
 	}
 
-	// SetCharSet - switch the client encoding
-	function SetCharSet($charset_name)
+	/**
+	 * Sets the client-side character set (encoding).
+	 *
+	 * Allows managing client encoding - very important if the database and
+	 * the output target (i.e. HTML) don't match; for instance, you may have a
+	 * UNICODE database and server your pages as WIN1251, etc.
+	 *
+	 * Supported on PostgreSQL 7.0 and above. Available charsets depend on
+	 * PostgreSQL version and the distribution's compile flags.
+	 *
+	 * @param string $charset The character set to switch to.
+	 *
+	 * @return bool True if the character set was changed successfully, false otherwise.
+	 */
+	function setCharSet($charset)
 	{
-		$this->GetCharSet();
-		if ($this->charSet !== $charset_name) {
-			$if = pg_set_client_encoding($this->_connectionID, $charset_name);
-			if ($if == "0" & $this->GetCharSet() == $charset_name) {
-				return true;
-			} else return false;
-		} else return true;
+		if ($this->charSet !== $charset) {
+			if (!$this->_connectionID || pg_set_client_encoding($this->_connectionID, $charset) != 0) {
+				return false;
+			}
+			$this->getCharSet();
+		}
+		return true;
 	}
 
 }
@@ -307,12 +328,6 @@ class ADORecordSet_postgres7 extends ADORecordSet_postgres64{
 
 	var $databaseType = "postgres7";
 
-
-	function __construct($queryID, $mode=false)
-	{
-		parent::__construct($queryID, $mode);
-	}
-
 	// 10% speedup to move MoveNext to child class
 	function MoveNext()
 	{
@@ -339,11 +354,6 @@ class ADORecordSet_assoc_postgres7 extends ADORecordSet_postgres64{
 	var $databaseType = "postgres7";
 
 
-	function __construct($queryID, $mode=false)
-	{
-		parent::__construct($queryID, $mode);
-	}
-
 	function _fetch()
 	{
 		if ($this->_currentRow >= $this->_numOfRows && $this->_numOfRows >= 0) {
