@@ -1,27 +1,34 @@
 <?php
-/*
-@version   v5.20.19  13-Dec-2020
-@copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
-@copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
-  Released under both BSD license and Lesser GPL library license.
-  Whenever there is any discrepancy between the two licenses,
-  the BSD license will take precedence.
-
-  Latest version is available at http://adodb.org/
-
-  SQLite info: http://www.hwaci.com/sw/sqlite/
-
-  Install Instructions:
-  ====================
-  1. Place this in adodb/drivers
-  2. Rename the file, remove the .txt prefix.
-*/
+/**
+ * SQLite driver
+ *
+ * @link https://www.sqlite.org/
+ *
+ * @deprecated Use SQLite3 driver instead
+ *
+ * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
+ *
+ * @package ADOdb
+ * @link https://adodb.org Project's web site and documentation
+ * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
+ *
+ * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
+ * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
+ * any later version. This means you can use it in proprietary products.
+ * See the LICENSE.md file distributed with this source code for details.
+ * @license BSD-3-Clause
+ * @license LGPL-2.1-or-later
+ *
+ * @copyright 2000-2013 John Lim
+ * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
+ */
 
 // security - hide paths
 if (!defined('ADODB_DIR')) die();
 
 class ADODB_sqlite extends ADOConnection {
 	var $databaseType = "sqlite";
+	var $dataProvider = "sqlite";
 	var $replaceQuote = "''"; // string to use to replace quotes
 	var $concat_operator='||';
 	var $_errorNo = 0;
@@ -33,10 +40,6 @@ class ADODB_sqlite extends ADOConnection {
 	var $sysTimeStamp = "adodb_date('Y-m-d H:i:s')";
 	var $fmtTimeStamp = "'Y-m-d H:i:s'";
 
-	function __construct()
-	{
-	}
-
 	function ServerInfo()
 	{
 		$arr['version'] = sqlite_libversion();
@@ -135,7 +138,7 @@ class ADODB_sqlite extends ADOConnection {
 		$parentDriver->hasInsertID = true;
 	}
 
-	function _insertid()
+	protected function _insertID($table = '', $column = '')
 	{
 		return sqlite_last_insert_rowid($this->_connectionID);
 	}
@@ -355,6 +358,63 @@ class ADODB_sqlite extends ADOConnection {
 		return $indexes;
 	}
 
+	/**
+	* Returns the maximum size of a MetaType C field. Because of the
+	* database design, sqlite places no limits on the size of data inserted
+	*
+	* @return int
+	*/
+	function charMax()
+	{
+		return ADODB_STRINGMAX_NOLIMIT;
+	}
+
+	/**
+	* Returns the maximum size of a MetaType X field. Because of the
+	* database design, sqlite places no limits on the size of data inserted
+	*
+	* @return int
+	*/
+	function textMax()
+	{
+		return ADODB_STRINGMAX_NOLIMIT;
+	}
+
+	/*
+	 * Converts a date to a month only field and pads it to 2 characters
+	 *
+	 * @param 	str		$fld	The name of the field to process
+	 * @return	str				The SQL Statement
+	 */
+	function month($fld)
+	{
+		$x = "strftime('%m',$fld)";
+
+		return $x;
+	}
+
+	/*
+	 * Converts a date to a day only field and pads it to 2 characters
+	 *
+	 * @param 	str		$fld	The name of the field to process
+	 * @return	str				The SQL Statement
+	 */
+	function day($fld) {
+		$x = "strftime('%d',$fld)";
+		return $x;
+	}
+
+	/*
+	 * Converts a date to a year only field
+	 *
+	 * @param 	str		$fld	The name of the field to process
+	 * @return	str				The SQL Statement
+	 */
+	function year($fld) {
+		$x = "strftime('%Y',$fld)";
+
+		return $x;
+	}
 }
 
 /*--------------------------------------------------------------------------------------
