@@ -1,21 +1,24 @@
 <?php
-/*
-@version   v5.20.19  13-Dec-2020
-@copyright (c) 2000-2013 John Lim. All rights reserved.
-@copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
-  Released under both BSD license and Lesser GPL library license.
-  Whenever there is any discrepancy between the two licenses,
-  the BSD license will take precedence.
-  Set tabs to 4 for best viewing.
-
-  Latest version is available at http://adodb.org/
-
-  Sybase driver contributed by Toni (toni.tunkkari@finebyte.com)
-
-  - MSSQL date patch applied.
-
-  Date patch by Toni 15 Feb 2002
-*/
+/**
+ * Sybase driver
+ *
+ * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
+ *
+ * @package ADOdb
+ * @link https://adodb.org Project's web site and documentation
+ * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
+ *
+ * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
+ * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
+ * any later version. This means you can use it in proprietary products.
+ * See the LICENSE.md file distributed with this source code for details.
+ * @license BSD-3-Clause
+ * @license LGPL-2.1-or-later
+ *
+ * @copyright 2000-2013 John Lim
+ * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
+ * @author Toni Tunkkari <toni.tunkkari@finebyte.com>
+ */
 
  // security - hide paths
 if (!defined('ADODB_DIR')) die();
@@ -44,15 +47,15 @@ class ADODB_sybase extends ADOConnection {
 
 	var $port;
 
-	function __construct()
-	{
-	}
-
-	// might require begintrans -- committrans
-	function _insertid()
+	/**
+	 * might require begintrans -- committrans
+	 * @inheritDoc
+	 */
+	protected function _insertID($table = '', $column = '')
 	{
 		return $this->GetOne('select @@identity');
 	}
+
 	  // might require begintrans -- committrans
 	function _affectedrows()
 	{
@@ -171,7 +174,7 @@ class ADODB_sybase extends ADOConnection {
 	{
 	global $ADODB_COUNTRECS;
 
-		if ($ADODB_COUNTRECS == false && ADODB_PHPVER >= 0x4300)
+		if ($ADODB_COUNTRECS == false)
 			return sybase_unbuffered_query($sql,$this->_connectionID);
 		else
 			return sybase_query($sql,$this->_connectionID);
@@ -320,7 +323,7 @@ class ADORecordset_sybase extends ADORecordSet {
 		}
 		if (!$mode) $this->fetchMode = ADODB_FETCH_ASSOC;
 		else $this->fetchMode = $mode;
-		parent::__construct($id,$mode);
+		parent::__construct($id);
 	}
 
 	/*	Returns: an object containing field information.
@@ -393,12 +396,8 @@ class ADORecordset_sybase extends ADORecordSet {
 }
 
 class ADORecordSet_array_sybase extends ADORecordSet_array {
-	function __construct($id=-1)
-	{
-		parent::__construct($id);
-	}
 
-		// sybase/mssql uses a default date like Dec 30 2000 12:00AM
+	// sybase/mssql uses a default date like Dec 30 2000 12:00AM
 	static function UnixDate($v)
 	{
 	global $ADODB_sybase_mths;
