@@ -1,61 +1,23 @@
 <?php
-
-
-/*
-@version   v5.20.19  13-Dec-2020
-@copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
-@copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
-         Contributed by Ross Smith (adodb@netebb.com).
-  Released under both BSD license and Lesser GPL library license.
-  Whenever there is any discrepancy between the two licenses,
-  the BSD license will take precedence.
-	  Set tabs to 4 for best viewing.
-
-
-*/
-
-/*
-
-CREATE Table SCripts
-
-Oracle
-======
-
-CREATE TABLE SESSIONS2
-(
-  SESSKEY    VARCHAR2(48 BYTE)                  NOT NULL,
-  EXPIRY     DATE                               NOT NULL,
-  EXPIREREF  VARCHAR2(200 BYTE),
-  CREATED    DATE                               NOT NULL,
-  MODIFIED   DATE                               NOT NULL,
-  SESSDATA   CLOB,
-  PRIMARY KEY(SESSKEY)
-);
-
-
-CREATE INDEX SESS2_EXPIRY ON SESSIONS2(EXPIRY);
-CREATE UNIQUE INDEX SESS2_PK ON SESSIONS2(SESSKEY);
-CREATE INDEX SESS2_EXP_REF ON SESSIONS2(EXPIREREF);
-
-
-
- MySQL
- =====
-
-CREATE TABLE sessions2(
-	sesskey VARCHAR( 64 ) NOT NULL DEFAULT '',
-	expiry TIMESTAMP NOT NULL ,
-	expireref VARCHAR( 250 ) DEFAULT '',
-	created TIMESTAMP NOT NULL ,
-	modified TIMESTAMP NOT NULL ,
-	sessdata LONGTEXT DEFAULT '',
-	PRIMARY KEY ( sesskey ) ,
-	INDEX sess2_expiry( expiry ),
-	INDEX sess2_expireref( expireref )
-)
-
-
-*/
+/**
+ * ADOdb Session Management
+ *
+ * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
+ *
+ * @package ADOdb
+ * @link https://adodb.org Project's web site and documentation
+ * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
+ *
+ * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
+ * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
+ * any later version. This means you can use it in proprietary products.
+ * See the LICENSE.md file distributed with this source code for details.
+ * @license BSD-3-Clause
+ * @license LGPL-2.1-or-later
+ *
+ * @copyright 2000-2013 John Lim
+ * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
+ */
 
 if (!defined('_ADODB_LAYER')) {
 	require realpath(dirname(__FILE__) . '/../adodb.inc.php');
@@ -100,7 +62,7 @@ function adodb_session_regenerate_id()
 	} else {
 		session_id(md5(uniqid(rand(), true)));
 		$ck = session_get_cookie_params();
-		setcookie(session_name(), session_id(), false, $ck['path'], $ck['domain'], $ck['secure']);
+		setcookie(session_name(), session_id(), false, $ck['path'], $ck['domain'], $ck['secure'], $ck['httponly']);
 		//@session_start();
 	}
 	$new_id = session_id();
@@ -110,7 +72,7 @@ function adodb_session_regenerate_id()
 	if (!$ok) {
 		session_id($old_id);
 		if (empty($ck)) $ck = session_get_cookie_params();
-		setcookie(session_name(), session_id(), false, $ck['path'], $ck['domain'], $ck['secure']);
+		setcookie(session_name(), session_id(), false, $ck['path'], $ck['domain'], $ck['secure'], $ck['httponly']);
 		return false;
 	}
 
@@ -158,7 +120,7 @@ class ADODB_Session {
 	*/
 	static function driver($driver = null)
 	{
-		static $_driver = 'mysql';
+		static $_driver = 'mysqli';
 		static $set = false;
 
 		if (!is_null($driver)) {
@@ -563,29 +525,44 @@ class ADODB_Session {
 #		assert('$database');
 #		assert('$driver');
 #		assert('$host');
-
-		$conn = ADONewConnection($driver);
-
-		if ($debug) {
-			$conn->debug = true;
-			ADOConnection::outp( " driver=$driver user=$user db=$database ");
-		}
-
-		if (empty($conn->_connectionID)) { // not dsn
+		if (strpos($driver, 'pdo_') === 0){
+			$conn = ADONewConnection('pdo');
+			$driver = str_replace('pdo_', '', $driver);
+			$dsn = $driver.':'.'hostname='.$host.';dbname='.$database.';';
 			if ($persist) {
 				switch($persist) {
 				default:
-				case 'P': $ok = $conn->PConnect($host, $user, $password, $database); break;
-				case 'C': $ok = $conn->Connect($host, $user, $password, $database); break;
-				case 'N': $ok = $conn->NConnect($host, $user, $password, $database); break;
+				case 'P': $ok = $conn->PConnect($dsn,$user,$password); break;
+				case 'C': $ok = $conn->Connect($dsn,$user,$password); break;
+				case 'N': $ok = $conn->NConnect($dsn,$user,$password); break;
 				}
 			} else {
-				$ok = $conn->Connect($host, $user, $password, $database);
+				$ok = $conn->Connect($dsn,$user,$password);
+			}
+		}else{
+			$conn = ADONewConnection($driver);
+			if ($debug) {
+				$conn->debug = true;
+				ADOConnection::outp( " driver=$driver user=$user db=$database ");
+			}
+
+			if (empty($conn->_connectionID)) { // not dsn
+				if ($persist) {
+					switch($persist) {
+					default:
+					case 'P': $ok = $conn->PConnect($host, $user, $password, $database); break;
+					case 'C': $ok = $conn->Connect($host, $user, $password, $database); break;
+					case 'N': $ok = $conn->NConnect($host, $user, $password, $database); break;
+					}
+				} else {
+					$ok = $conn->Connect($host, $user, $password, $database);
+				}
+			} else {
+				$ok = true; // $conn->_connectionID is set after call to ADONewConnection
 			}
-		} else {
-			$ok = true; // $conn->_connectionID is set after call to ADONewConnection
 		}
 
+
 		if ($ok) $GLOBALS['ADODB_SESS_CONN'] = $conn;
 		else
 			ADOConnection::outp('<p>Session: connection failed</p>', false);
@@ -628,7 +605,7 @@ class ADODB_Session {
 		$sql = "SELECT $ADODB_SESSION_SELECT_FIELDS FROM $table WHERE sesskey = $binary ".$conn->Param(0)." AND expiry >= " . $conn->sysTimeStamp;
 
 		/* Lock code does not work as it needs to hold transaction within whole page, and we don't know if
-		  developer has commited elsewhere... :(
+		  developer has committed elsewhere... :(
 		 */
 		#if (ADODB_Session::Lock())
 		#	$rs = $conn->RowLock($table, "$binary sesskey = $qkey AND expiry >= " . time(), sessdata);
@@ -806,7 +783,7 @@ class ADODB_Session {
 		//assert('$table');
 
 		$qkey = $conn->quote($key);
-		$binary = $conn->dataProvider === 'mysql' ? '/*! BINARY */' : '';
+		$binary = $conn->dataProvider === 'mysql' || $conn->dataProvider === 'pdo' ? '/*! BINARY */' : '';
 
 		if ($expire_notify) {
 			reset($expire_notify);
@@ -926,12 +903,12 @@ ADODB_Session::_init();
 if (empty($ADODB_SESSION_READONLY))
 	register_shutdown_function('session_write_close');
 
-// for backwards compatability only
+// for backwards compatibility only
 function adodb_sess_open($save_path, $session_name, $persist = true) {
 	return ADODB_Session::open($save_path, $session_name, $persist);
 }
 
-// for backwards compatability only
+// for backwards compatibility only
 function adodb_sess_gc($t)
 {
 	return ADODB_Session::gc($t);
